==> kubernetes-model-1.0.54-sources.jar: io/fabric8/openshift/api/model/SourceBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class SourceBuildStrategyBuilder extends SourceBuildStrategyFluentImpl<SourceBuildStrategyBuilder> implements VisitableBuilder<SourceBuildStrategy,SourceBuildStrategyBuilder>{

    SourceBuildStrategyFluent<?> fluent;
    Boolean validationEnabled;

    public SourceBuildStrategyBuilder(){
            this(true);
    }
    public SourceBuildStrategyBuilder(Boolean validationEnabled){
            this(new SourceBuildStrategy(), validationEnabled);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent){
            this(fluent, true);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SourceBuildStrategy(), validationEnabled);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent,SourceBuildStrategy instance){
            this(fluent, instance, true);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent,SourceBuildStrategy instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withEnv(instance.getEnv()); 
            fluent.withForcePull(instance.getForcePull()); 
            fluent.withFrom(instance.getFrom()); 
            fluent.withIncremental(instance.getIncremental()); 
            fluent.withPullSecret(instance.getPullSecret()); 
            fluent.withRuntimeArtifacts(instance.getRuntimeArtifacts()); 
            fluent.withRuntimeImage(instance.getRuntimeImage()); 
            fluent.withScripts(instance.getScripts()); 
            this.validationEnabled = validationEnabled; 
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategy instance){
            this(instance,true);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategy instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withEnv(instance.getEnv()); 
            this.withForcePull(instance.getForcePull()); 
            this.withFrom(instance.getFrom()); 
            this.withIncremental(instance.getIncremental()); 
            this.withPullSecret(instance.getPullSecret()); 
            this.withRuntimeArtifacts(instance.getRuntimeArtifacts()); 
            this.withRuntimeImage(instance.getRuntimeImage()); 
            this.withScripts(instance.getScripts()); 
            this.validationEnabled = validationEnabled; 
    }

    public SourceBuildStrategy build(){
            SourceBuildStrategy buildable = new SourceBuildStrategy(fluent.getEnv(),fluent.isForcePull(),fluent.getFrom(),fluent.isIncremental(),fluent.getPullSecret(),fluent.getRuntimeArtifacts(),fluent.getRuntimeImage(),fluent.getScripts());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SourceBuildStrategyBuilder that = (SourceBuildStrategyBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/openshift/api/model/SourceBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class SourceBuildStrategyBuilder extends SourceBuildStrategyFluentImpl<SourceBuildStrategyBuilder> implements VisitableBuilder<SourceBuildStrategy,SourceBuildStrategyBuilder>{

    SourceBuildStrategyFluent<?> fluent;
    Boolean validationEnabled;

    public SourceBuildStrategyBuilder(){
            this(true);
    }
    public SourceBuildStrategyBuilder(Boolean validationEnabled){
            this(new SourceBuildStrategy(), validationEnabled);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent){
            this(fluent, true);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SourceBuildStrategy(), validationEnabled);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent,SourceBuildStrategy instance){
            this(fluent, instance, true);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent,SourceBuildStrategy instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withEnv(instance.getEnv()); 
            fluent.withForcePull(instance.getForcePull()); 
            fluent.withFrom(instance.getFrom()); 
            fluent.withIncremental(instance.getIncremental()); 
            fluent.withPullSecret(instance.getPullSecret()); 
            fluent.withRuntimeArtifacts(instance.getRuntimeArtifacts()); 
            fluent.withRuntimeImage(instance.getRuntimeImage()); 
            fluent.withScripts(instance.getScripts()); 
            this.validationEnabled = validationEnabled; 
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategy instance){
            this(instance,true);
    }
    public SourceBuildStrategyBuilder(SourceBuildStrategy instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withEnv(instance.getEnv()); 
            this.withForcePull(instance.getForcePull()); 
            this.withFrom(instance.getFrom()); 
            this.withIncremental(instance.getIncremental()); 
            this.withPullSecret(instance.getPullSecret()); 
            this.withRuntimeArtifacts(instance.getRuntimeArtifacts()); 
            this.withRuntimeImage(instance.getRuntimeImage()); 
            this.withScripts(instance.getScripts()); 
            this.validationEnabled = validationEnabled; 
    }

    public SourceBuildStrategy build(){
            SourceBuildStrategy buildable = new SourceBuildStrategy(fluent.getEnv(),fluent.isForcePull(),fluent.getFrom(),fluent.isIncremental(),fluent.getPullSecret(),fluent.getRuntimeArtifacts(),fluent.getRuntimeImage(),fluent.getScripts());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SourceBuildStrategyBuilder that = (SourceBuildStrategyBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
